pub enum ControllerProviderRequest {
Connect {
controller: ServerEnd<ControllerMarker>,
responder: ControllerProviderConnectResponder,
},
Stop {
control_handle: ControllerProviderControlHandle,
},
}Expand description
Provides a Controller implementation.
This protocol is implemented by the fuzzing engine. This capability is not
routed. Instead, the engine uses the fuchsia.fuzzer/Registry channel
provided by the fuzz-test-runner to send the client end of this interface to
the fuzz-registry.
The fuzz-registry will close the channel upon error, or upon its own exit. The fuzzer should exit and not attempt to reconnect when on channel close.
Variants
Connect
Connects a client to the fuzzer.
Within the component fuzzing framework, the fuzz-manager forwards
Controller connection requests to the fuzz-registry, which uses
clients of this interface provided by the fuzzers themselves to perform
the connection.
At most one client can be connected to a controller at any given time.
A subsequent call to Connect will preempt and replace the existing
connection.
- request
controllerthe connection from the client.
Stop
Interrupt any current workflow, closes the channel, and exits the fuzzing engine.
Fields
control_handle: ControllerProviderControlHandleImplementations
Sourceimpl ControllerProviderRequest
impl ControllerProviderRequest
pub fn into_connect( self, ) -> Option<(ServerEnd<ControllerMarker>, ControllerProviderConnectResponder)>
pub fn into_stop(self) -> Option<ControllerProviderControlHandle>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL