pub struct OutputFlags(/* private fields */);Expand description
Specifies how a fuzzing engine should configure output streams.
Flags may be combined, e.g. CLOSE_STDOUT | CLOSE_STDERR. Support for each
flag is engine-specific. Specifying an unsupported output mode flag may
cause Controller.Configure to return ZX_ERR_NOT_SUPPORTED.
Implementations
Sourceimpl OutputFlags
impl OutputFlags
Sourcepub const CLOSE_STDOUT: OutputFlags
pub const CLOSE_STDOUT: OutputFlags
Suppress standard output from the engine process. This is analogous to
libFuzzer’s -close_fd_mask=1.
Sourcepub const CLOSE_STDERR: OutputFlags
pub const CLOSE_STDERR: OutputFlags
Suppress standard error from the engine process. Use with care: this may
remove diagnostic output from the target code (e.g. messages on assert
failure). This is analogous to libFuzzer’s -close_fd_mask=2.
Sourcepub const VERBOSE: OutputFlags
pub const VERBOSE: OutputFlags
Produce more verbose output from the fuzzer engine. The exact meaning of
“more verbose” is engine-specific. This is analogous to libFuzzer’s
-verbosity=2.
Sourcepub const LIBFUZZER: OutputFlags
pub const LIBFUZZER: OutputFlags
Produce libFuzzer-style output on standard error. This facilitates integration with systems like ClusterFuzz. See https://llvm.org/docs/LibFuzzer.html#output for example output.
Sourceimpl OutputFlags
impl OutputFlags
Sourcepub const fn empty() -> OutputFlags
pub const fn empty() -> OutputFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> OutputFlags
pub const fn all() -> OutputFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<OutputFlags>
pub const fn from_bits(bits: u32) -> Option<OutputFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> OutputFlags
pub const fn from_bits_truncate(bits: u32) -> OutputFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> OutputFlags
pub const fn from_bits_retain(bits: u32) -> OutputFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<OutputFlags>
pub fn from_name(name: &str) -> Option<OutputFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: OutputFlags) -> bool
pub const fn intersects(&self, other: OutputFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: OutputFlags) -> bool
pub const fn contains(&self, other: OutputFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: OutputFlags)
pub fn insert(&mut self, other: OutputFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: OutputFlags)
pub fn remove(&mut self, other: OutputFlags)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: OutputFlags)
pub fn toggle(&mut self, other: OutputFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: OutputFlags, value: bool)
pub fn set(&mut self, other: OutputFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: OutputFlags) -> OutputFlags
pub const fn intersection(self, other: OutputFlags) -> OutputFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: OutputFlags) -> OutputFlags
pub const fn union(self, other: OutputFlags) -> OutputFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: OutputFlags) -> OutputFlags
pub const fn difference(self, other: OutputFlags) -> OutputFlags
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: OutputFlags) -> OutputFlags
pub const fn symmetric_difference(self, other: OutputFlags) -> OutputFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> OutputFlags
pub const fn complement(self) -> OutputFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl OutputFlags
impl OutputFlags
Sourcepub const fn iter(&self) -> Iter<OutputFlags>
pub const fn iter(&self) -> Iter<OutputFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<OutputFlags>
pub const fn iter_names(&self) -> IterNames<OutputFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.