pub struct TargetAdapterProxy { /* private fields */ }Implementations
Sourceimpl TargetAdapterProxy
impl TargetAdapterProxy
Sourcepub fn take_event_stream(&self) -> TargetAdapterEventStream
pub fn take_event_stream(&self) -> TargetAdapterEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn get_parameters(
&self,
) -> QueryResponseFut<Vec<String>, FDomainResourceDialect>
pub fn get_parameters( &self, ) -> QueryResponseFut<Vec<String>, FDomainResourceDialect>
Retrieves the target-specific fuzzer parameters, e.g. the package- relative location of seed corpora. These parameters are specific to individual fuzzers, and are used by both the fuzzing engine and the “test-engine” used to create fuzzer unit tests. For these reasons, it is most convenient for fuzzer authors to specify them as part of the (fuzzer-specific) target adapter’s component manifest file, and have the engine and test-engine retrieve them via this method.
- response
parametersthe command line parameters from a specific fuzzer’s component manifest.
Sourcepub fn connect(
&self,
eventpair: EventPair,
test_input: Vmo,
) -> QueryResponseFut<(), FDomainResourceDialect>
pub fn connect( &self, eventpair: EventPair, test_input: Vmo, ) -> QueryResponseFut<(), FDomainResourceDialect>
Provides the eventpair used by driver and adapter to signal each other,
and the shared VMO used to provide test inputs to the adapter. The VMO
must have the ZX_PROP_VMO_CONTENT_SIZE property set.
- request
eventpairthe eventpair used to signal when fuzzing runs start and stop. - request
test_inputthe shared VMO used by the engine to provide byte sequences to test.